<?php

/**
 * Add function to widgets_init that'll load our widget.
 * @since 0.1
 */
add_action( 'widgets_init', 'load_Login_Widget' );

/**
 * Register our widget.
 * 'Example_Widget' is the widget class used below.
 *
 * @since 0.1
 */
function load_Login_Widget() {
	register_widget( 'Login_Widget' );
}

/**
 * Example Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
class Login_Widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function Login_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'login_widget', 'description' => __( 'This Widget outputs a form for your subscribers to login.', 'c4s' ) );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'login-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'login-widget', __( 'Subscriber Login', 'c4s' ), $widget_ops, $control_ops );
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		global $wpdb, $c4s_error, $c4s_errormsg;
		extract( $args );
		$hash = md5( implode( ",", $instance ) );
		$instance["hash"] = $hash;
		$instance["error"] = false;
		if(isset( $_POST["c4s"] ) &&  $hash == $_POST["c4s"]["hash"] ){
			$instance["error"] = $c4s_error;
			$instance["errormsg"] = $c4s_errormsg;
		}
		/* Before widget (defined by themes). */
		echo $before_widget;
		echo $before_title . $instance["title"] . $after_title;
		if( !isset( $_SESSION["c4s"]["lists"][ $instance["service"] ][ $instance["listid"] ]["is_subscriber"] ) || !$_SESSION["c4s"]["lists"][ $instance["service"] ][ $instance["listid"] ]["is_subscriber"] )
			require_template( 'widget_login.php', $instance );
		else
			require_template( 'widget_login_confirm.php', $instance );
		

		/* After widget (defined by themes). */
		echo $after_widget;
		wp_reset_query();
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] =  $new_instance['title'] ;
		$instance['listid'] =  $new_instance['listid'] ;
		$instance['service'] =  $new_instance['service'] ;

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => __( 'Login', 'c4s' ) );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title', 'c4s' ); ?>:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'service' ); ?>"><?php _e( 'Service', 'c4s' ); ?>:</label>
				<select id="<?php echo $this->get_field_id( 'service' ); ?>" name="<?php echo $this->get_field_name( 'service' ); ?>">
					<option <?php if( $instance['service'] == 'mailchimp' ) echo 'selected="selected" '; ?>value="mailchimp">MailChimp</option>
					<option <?php if( $instance['service'] == 'cleverreach' ) echo 'selected="selected" '; ?>value="cleverreach">CleverReach</option>
				</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'listid' ); ?>"><?php _e( 'List ID', 'c4s' ); ?>:</label>
			<input id="<?php echo $this->get_field_id( 'listid' ); ?>" name="<?php echo $this->get_field_name( 'listid' ); ?>" value="<?php echo $instance['listid']; ?>" />
		</p>

		

	<?php
	}
}

?>